@@ -2,7 +2,6 @@
 import asyncio
 import socket
 from typing import Any, Optional, List
-import subprocess
 
 import aiohttp
 import async_timeout
@@ -11,8 +10,7 @@ from yarl import URL
 from .__version__ import __version__
 from .exceptions import AqmanError, AqmanConnectionError
 from .models import Device, UserInfo
-from .const import BASE_URL, SUPPORTED_INTERFACES
-from .utils import get_ip_address, get_interfaces
+from .const import BASE_URL
 
 
 class AqmanUser:
@@ -20,46 +18,47 @@ class AqmanUser:
 
     def __init__(
             self,
-            host: str = None,
-            port: int = 8297,
+            id: str = None,
+            password: str = None,
+            host: str = BASE_URL,
             request_timeout: int = 10,
             session: aiohttp.ClientSession = None):
         """Initialize the AqmanUser class"""
         self._session = session
+        self._close_session = False
+
+        self._id = id
+        self._password = password
         self._host = host
-        self._port = port
         self._request_timeout = request_timeout
-        self._interfaces = None
-        self._host_ip = None
-
-        # Sets the variables _interfaces, _host_ip, and _host
-        self._find_host_ip()
-
-    def _find_host_ip(self):
-        interfaces = get_interfaces()
-        self._interfaces = interfaces
-
-        for interface in SUPPORTED_INTERFACES:
-            if interface in interfaces:
-                ip_address = get_ip_address(interface)
-                self._host_ip = ip_address
-                break
-
-        self._host = f"{ip_address}:{self._port}/api"
+        self._token = None
 
     async def _request(self, uri: str, data: Optional[dict] = None,) -> Any:
         """Handle a request to a Aqman101"""
-        url = URL.build(scheme="http", host=self._host, path=f"/{uri}")
-        method = "GET"
+        url = URL.build(scheme="https", host=self._host, path=f"/{uri}")
+
+        if uri == "login":
+            method = "POST"
+        else:
+            method = "GET"
+            headers = {
+                "Token": f"{self._token}"
+            }
 
         if self._session is None:
             self._session = aiohttp.ClientSession()
+            self._close_session = True
 
         try:
             with async_timeout.timeout(self._request_timeout):
-                response = await self._session.request(
-                    method, str(url)
-                )
+                if method == "POST":
+                    response = await self._session.request(
+                        method, str(url), json=data,
+                    )
+                elif method == "GET":
+                    response = await self._session.request(
+                        method, str(url), params=data, headers=headers
+                    )
                 response.raise_for_status()
         except asyncio.TimeoutError as exception:
             raise AqmanConnectionError(
@@ -84,14 +83,23 @@ class AqmanUser:
 
         return await response.json()
 
+    async def token(self) -> str:
+        """Get the token for current session of Aqman101"""
+        data = await self._request("login", data={"id": self._id, "password": self._password})
+        web_token = data['tokenWeb']
+        self._token = web_token
+        return web_token
+
     async def devices_info(self) -> List[str]:
         """Get the list of serial numbers for current user of Aqman101"""
-        data = await self._request("devices")
-        return UserInfo.from_list(data['devices'])
+        if self._token == None:
+            await self.token()
+        data = await self._request("devices", data={"customerId": self._id})
+        return UserInfo.from_list(self._id, self._password, data)
 
     async def close(self) -> None:
         """Close open client session."""
-        if self._session:
+        if self._session and self._close_session:
             await self._session.close()
 
     async def __aenter__(self) -> "Aqman":
@@ -108,49 +116,49 @@ class AqmanDevice:
 
     def __init__(
             self,
+            id: str = None,
+            password: str = None,
             deviceid: str = None,
-            host: str = None,
-            port: int = 8297,
+            host: str = BASE_URL,
             request_timeout: int = 10,
             session: aiohttp.ClientSession = None) -> None:
         """Initialize Connection with AQMAN101"""
-        self._deviceid = deviceid
         self._session = session
+        self._close_session = False
+
+        self._id = id
+        self._password = password
+        self._deviceid = deviceid
         self._host = host
-        self._port = port
         self._request_timeout = request_timeout
-        self._interfaces = None
-        self._host_ip = None
+        self._token = None
 
-        # Sets the variables _interfaces, _host_ip, and _host
-        self._find_host_ip()
-
-    def _find_host_ip(self):
-        interfaces = get_interfaces()
-        self._interfaces = interfaces
-
-        for interface in SUPPORTED_INTERFACES:
-            if interface in interfaces:
-                ip_address = get_ip_address(interface)
-                self._host_ip = ip_address
-                break
-
-        self._host = f"{ip_address}:{self._port}/api"
-
-    async def _request(self, uri: str, data: str,) -> Any:
+    async def _request(self, uri: str, data: Optional[dict] = None,) -> Any:
         """Handle a request to a Aqman101"""
-        # Scheme is HTTP!!
-        url = URL.build(scheme="http", host=self._host, path=f"/{uri}/{data}")
-        method = "GET"
+        url = URL.build(scheme="https", host=self._host, path=f"/{uri}")
+
+        if uri == "login":
+            method = "POST"
+        else:
+            method = "GET"
+            headers = {
+                "Token": f"{self._token}"
+            }
 
         if self._session is None:
             self._session = aiohttp.ClientSession()
+            self._close_session = True
 
         try:
             with async_timeout.timeout(self._request_timeout):
-                response = await self._session.request(
-                    method, str(url)
-                )
+                if method == "POST":
+                    response = await self._session.request(
+                        method, str(url), json=data,
+                    )
+                elif method == "GET":
+                    response = await self._session.request(
+                        method, str(url), params=data, headers=headers
+                    )
                 response.raise_for_status()
         except asyncio.TimeoutError as exception:
             raise AqmanConnectionError(
@@ -161,28 +169,9 @@ class AqmanDevice:
             aiohttp.ClientResponseError,
             socket.gaierror,
         ) as exception:
-            from datetime import datetime
-
-            now = datetime.now()
-
-            current_time = now.strftime("%Y/%m/%d, %H:%M:%S")
-            error_data = {
-                "sn": data,
-                "dsm101_sn": "",
-                "dt": current_time,
-                "temp": -2,
-                "humi": -2,
-                "co2": -2,
-                "pm1": -2,
-                "pm2d5": -2,
-                "pm10": -2,
-                "radon": -2,
-                "tvoc": -2,
-            }
-            return error_data
-            # raise AqmanConnectionError(
-            #     "Error occurred while communicating with Aqman 101"
-            # ) from exception
+            raise AqmanConnectionError(
+                "Error occurred while communicating with Aqman 101"
+            ) from exception
 
         content_type = response.headers.get("Content-Type", "")
         if "application/json" not in content_type:
@@ -194,14 +183,23 @@ class AqmanDevice:
 
         return await response.json()
 
+    async def token(self) -> str:
+        """Get the token for current session of Aqman101"""
+        data = await self._request("login", data={"id": self._id, "password": self._password})
+        web_token = data['tokenWeb']
+        self._token = web_token
+        return web_token
+
     async def state(self) -> Device:
         """Get the current state of Aqman101"""
-        data = await self._request("device", self._deviceid)
+        if self._token is None:
+            await self.token()
+        data = await self._request("devices", data={"sn": self._deviceid})
         return Device.from_dict(data)
 
     async def close(self) -> None:
         """Close open client session."""
-        if self._session:
+        if self._session and self._close_session:
             await self._session.close()
 
     async def __aenter__(self) -> "Aqman":
